@@ -12,13 +12,12 @@ class Banks(ListoAPI):
                .json()['facets']['bank_account']
 
     def upload_bank_files(self, filename, file_stream, bank=None, account_number=None, currency=None, rfc_id=None):
-        return self.make_request(method="POST", path="/banks/upload_bank_files",
+        print('Uploading file:', filename)
+        return self.make_request(method="POST", path="/banks/upload_bank_files/sync",
                                  files={'file': file_stream},
-                                 data={filename: {
-                                    "bank": bank,
-                                    "account_number": account_number,
-                                    "currency": currency,
-                                    "rfc_id": rfc_id}}).json()['status']
+                                 data={filename:
+                                    '{"bank": "%s", "account_number": "%s", "currency": "%s", "rfc_id": %s}' %
+                                     (bank, account_number, currency, rfc_id)}).json()['status']
 
     def get_bank_transactions(self, **kwargs):
         return self.make_request(method="GET", path="/banks/bank_transaction", params=kwargs) \
